<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\AlarmOrder;
use Illuminate\Support\Facades\DB;
use App\Models\AlarmOrderSchedule;

class AlarmOrderController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        if($this->isadmin()) {
            $limit = 20;
            $offset = $limit * ($request->input('page') - 1);
            $orders = AlarmOrder::selectRaw('FROM_UNIXTIME(r.starttime) AS start_time, FROM_UNIXTIME(r.endtime) AS end_time, alarm_order.*, r.devicenumber, r.concentration, r.location, r.policestatus, r.shutoff_status')
                ->leftjoin('reportpolice AS r', 'r.id', '=', 'alarm_order.reportpolice_id')
                ->offset($offset)
                ->limit($limit)
                ->get()->toArray();
            return $this->jsonSuccessData($orders);
        }else{
            return $this->jsonErrorData(500, '没有权限，请联系管理员');
        }


    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $reportpolice_id = $request->input('reportpolice_id');
        $orderNum = date('YmdHis') .
                substr($request->input('device_num'), -4).
                $request->input('policestatus').
                $request->input('shutoff_status');
        $order = new AlarmOrder();
        $insertId = $order->sharedLock()->insertGetId([
            'order_num' => $orderNum,
            'reportpolice_id' => $reportpolice_id,
        ]);

        // 进度表新增
        $orderSchedule = new AlarmOrderSchedule();
        $orderSchedule->lockForUpdate();
        $orderSchedule->alarm_order_id = $insertId;
        $orderSchedule->schedule = 1;
        $orderSchedule->save();

        if($insertId) {
            return $this->jsonSuccessData('已生成工单！');
        }else{
            return $this->jsonErrorData('工单创建失败');
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $order = AlarmOrder::select('*')
            ->join('reportpolice AS r', 'r.id', '=', 'alarm_order.reportpolice_id')
            ->where('alarm_order.id', '=', $id)
            ->get();
        $this->jsonSuccessData($order);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $order = AlarmOrder::where('id', $id)
            ->update($request->all());
        if($order) {
            $this->jsonSuccessData('工单更新成功');
        }else{
            $this->jsonErrorData(500, '更新订单失败！');
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $state = AlarmOrder::destroy($id);
        if($state) {
            $this->jsonSuccessData('删除成功');
        }else{
            $this->jsonErrorData(500, '删除工单失败！');
        }
    }
}
